import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

import 'package:hangman/provider/data.dart';
import 'package:hangman/utils/constants.dart';

class Scores extends StatelessWidget {
  const Scores({super.key});

  static const String id = 'scores';

  @override
  Widget build(BuildContext context) {
    final Data myProvider = Provider.of<Data>(context);

    return Scaffold(
      backgroundColor: const Color(board),
      appBar: AppBar(
        title: const Text('Scores'),
        actions: [
          IconButton(
            icon: const Icon(Icons.delete_forever),
            onPressed: () => myProvider.resetScores(),
          ),
        ],
      ),
      body: SafeArea(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.start,
          children: [
            const Flexible(
              child: FractionallySizedBox(heightFactor: 0.6),
            ),
            Padding(
              padding: const EdgeInsets.symmetric(horizontal: 10.0),
              child: FittedBox(
                fit: BoxFit.fitWidth,
                child: Text(
                  'SCORES',
                  style: TextStyle(
                    fontFamily: 'Tiza',
                    fontSize: 28.0,
                    color: Colors.grey[300],
                  ),
                ),
              ),
            ),
            const Flexible(child: FractionallySizedBox(heightFactor: 0.2)),
            Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                CardBox(
                  Icon(
                    Icons.emoji_events,
                    color: Colors.grey[200],
                    size: 60.0,
                  ),
                  '${myProvider.victoryCount}',
                ),
                CardBox(
                  ImageIcon(
                    const AssetImage('assets/images/gameover.png'),
                    color: Colors.grey[200],
                    size: 60.0,
                  ),
                  '${myProvider.defeatCount}',
                ),
              ],
            ),
          ],
        ),
      ),
    );
  }
}

class CardBox extends StatelessWidget {
  final Widget imagen;
  final String text;

  const CardBox(this.imagen, this.text, {super.key});

  @override
  Widget build(BuildContext context) {
    return Flexible(
      child: Card(
        elevation: 10.0,
        margin: const EdgeInsets.symmetric(horizontal: 10.0),
        shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(10)),
        color: const Color(darkGreen),
        child: Column(
          children: [
            Container(
              padding: const EdgeInsets.all(10.0),
              decoration: const BoxDecoration(
                border: Border(
                  bottom: BorderSide(
                    color: Colors.grey,
                    width: 0.5,
                  ),
                ),
              ),
              child: Padding(
                padding: const EdgeInsets.all(10.0),
                child: imagen,
              ),
            ),
            Container(
              padding: const EdgeInsets.all(20.0),
              child: Text(
                text,
                style: TextStyle(
                  fontFamily: 'Tiza',
                  fontSize: 20.0,
                  color: Colors.grey[300],
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }
}
